@@ -11,14 +11,14 @@ QUERY = """mutation updateInfinityZoneActivity($input: InfinityZoneActivityInput
 }"""
 
 
-def update_activity_query(
+def update_activity_temp_query(
     serial: str,
     zone_id: str,
     activity_type: str,
     target_cooling_temperature: int,
     target_heating_temperature: int,
 ) -> dict:
-    """Generate GraphQL query for updateInfinityZoneActivity"""
+    """Generate GraphQL query for updateInfinityZoneActivity temperature"""
 
     return {
         "operationName": OPERATION,
@@ -33,3 +33,22 @@ def update_activity_query(
         },
         "query": QUERY,
     }
+
+
+def update_activity_fan_query(
+    serial: str, zone_id: str, activity_type: str, fan: str
+) -> dict:
+    """Generate GraphQL query for updateInfinityZoneActivity fan"""
+
+    return {
+        "operationName": OPERATION,
+        "variables": {
+            "input": {
+                "serial": serial,
+                "zoneId": zone_id,
+                "activityType": activity_type,
+                "fan": fan,
+            },
+        },
+        "query": QUERY,
+    }
